#!/usr/bin/env python3

"""App to lint Axii's modules for general conventions."""

import json

from armarx_setup.core.module import Module
from armarx_setup.core.util.json.module_lint import ModuleLinter


def main():
    reports = []

    modules = Module.get_all_module_names()
    for module in modules:
        for issue in ModuleLinter(module).lint():
            report = {
                "description": issue.description,
                "fingerprint": issue.fingerprint,
                "severity": issue.severity,
                "location": {
                    "path": issue.path,
                    "lines": {
                        "begin": issue.line
                    }
                }
            }

            reports.append(report)

    print(json.dumps(reports, indent=2))


if __name__ == "__main__":
    main()
