"""Integrates edit CLI commands to Axii's core."""

import os

import typing as ty

from armarx_setup.cli import common
from armarx_setup.core import error


def edit_module_config(
        module_name: ty.Optional[str],
        this: bool,
):
    """Edit the configuration of a specific module."""

    # Edit the module_config.
    from armarx_setup.core.config import config as axii_config
    from armarx_setup.core.module.module import Module
    console = axii_config.console

    if this and module_name is not None:
        raise error.AxiiError("You may specify either 'module_name' or '--this', but not both.")
    if not this and module_name is None:
        raise error.AxiiError("Missing argument/option: specify either 'module_name' or '--this'")

    if this:
        assert module_name is None, module_name

        # Get module path from current working directory.
        # This requires an activated workspace.
        from armarx_setup.cli.workspace.integration import get_workspace_by_name_or_active

        path = os.getcwd()
        console.print(f"Requested to edit module explaining the path '{path}'. "
                      f"This requires an active workspace.")

        ws = get_workspace_by_name_or_active()
        console.print(f"Loaded workspace '{ws.name}' at '{ws.path}'.")

        module_path = os.path.abspath(os.path.expandvars(path))
        module = ws.module_graph.find_module_explaining_path(module_path, ws_path=ws.path)
        console.print(f"Found module '{module.name}'")

    else:
        assert module_name is not None

        module = Module(module_name)

    tmp_file_name = f"module: {module.name}.json"
    return common.open_file_in_editor(module.get_info_path(module.name), kind="module definition",
                                      tmp_file_name=tmp_file_name)


def edit_workspace_config(workspace_name):
    """Edit the workspace configuration file of the active workspace."""
    from armarx_setup.core.workspace import Workspace

    if workspace_name is not None:
        ws = Workspace.load_workspace_by_name(workspace_name)
    else:
        ws = Workspace.load_active_workspace()

    tmp_file_name = f"workspace: {ws.name} - armarx-workspace.json"
    return common.open_file_in_editor(ws.get_config_path(), kind="workspace configuration",
                                      tmp_file_name=tmp_file_name)


def edit_global_config(**kwargs):
    """Edit the global Axii configuration file."""
    from armarx_setup.core.config import config

    tmp_file_name = "global_config.json"
    common.open_file_in_editor(config.global_config_file_path, kind="global configuration",
                               tmp_file_name=tmp_file_name)
