import dataclasses as dc
from typing import List, Optional

from armarx_setup.core.module import common
from armarx_setup.core.module.context import Hook
from armarx_setup.core.module.prepare.cmake import CMake
from armarx_setup.core.module.prepare.python import Python
from armarx_setup.core.module.prepare.run import Run
from armarx_setup.core.module.prepare.extract import Extract


@dc.dataclass
class Prepare(Hook):
    cmake: Optional[CMake] = None
    run: Optional[Run] = None
    python: Optional[Python] = None
    extract: Optional[Extract] = None

    def __post_init__(self):
        from armarx_setup.core.util.dataclass import sanitize_type

        kwargs = { "ctx": self.ctx }
        sub_step_enabled_kwargs = { "list_factory": common.SubStepAdapter.list_factory, **kwargs }

        self.cmake = sanitize_type(self.cmake, CMake, **sub_step_enabled_kwargs)
        self.run = sanitize_type(self.run, Run, **sub_step_enabled_kwargs)
        self.python = sanitize_type(self.python, Python, **sub_step_enabled_kwargs)
        self.extract = sanitize_type(self.extract, Extract, **sub_step_enabled_kwargs)

    def _get_sub_hooks(self) -> List["Hook"]:
        return [self.cmake, self.run, self.python, self.extract]

    def test(self, **kwargs) -> Optional[bool]:
        for hook in self._get_sub_hooks():
            if hook is not None:
                return hook.test(**kwargs)
