import abc
import shutil
import sys

from rich.text import Text

from armarx_setup import console


class Console:
    """Interface of a console to interact with a CLI."""

    @abc.abstractmethod
    def print(self, *args, **kwargs):
        ...

    @abc.abstractmethod
    def print_error(self, *args, **kwargs):
        ...

    @abc.abstractmethod
    def print_exception(self):
        ...


class StdConsole(Console):
    """Implementation of a console using standard Python print."""

    def print(self, *args, **kwargs):
        assert "file" not in kwargs
        print(*args, **kwargs)

    def print_error(self, *args, **kwargs):
        assert "file" not in kwargs
        print(*args, file=sys.stderr, **kwargs)

    def print_exception(self):
        import traceback
        traceback.print_exc()
        self.print()


def print_full_width_heading(text: str, sep_color="white", indentation=3):
    text_width = len(Text.from_markup(text))
    # click.get_terminal_size() was removed in 8.1.0.
    # see https://click.palletsprojects.com/en/8.1.x/changes/#version-8-1-0
    term_width = shutil.get_terminal_size()[0]

    console.print()
    console.print(f"[{sep_color}]{'━' * term_width}")
    console.print(
        f"[{sep_color}]{'─' * indentation}[/] {text} [{sep_color}]{'─' * (term_width - (indentation + 2) - text_width)}[/]")
    console.print(f"[{sep_color}]{'━' * term_width}")
