import os


class Home:

    def __init__(self, workspace_path):
        self.installed_executable: list[str] = []
        self.home_path = os.path.join(workspace_path, ".axii")
        self.bin_path = os.path.join(self.home_path, "bin")

    def _write_executable(self, name, f, exec_config, kill_trap, fork):
        from armarx_setup.core.config import config as axii_config
        console = axii_config.console

        def resolve_vars(input):
            output = os.path.expandvars(input.replace('\\$', '--$--')).replace('--$--', "$")
            return output

        f.write("#!/bin/bash\n")
        f.write("\n")
        if kill_trap:
            f.write("trap : SIGTERM SIGINT\n")
            f.write("\n")
        if "pre_exec_commands" in exec_config and len(
                exec_config["pre_exec_commands"]) > 0:
            for cmd in exec_config["pre_exec_commands"]:
                f.write(f"{resolve_vars(cmd)}\n")
            f.write("\n")
        args = ""
        if "exec_args" in exec_config:
            args = " ".join(resolve_vars(x) for x in exec_config['exec_args'])
        f.write(f"{resolve_vars(exec_config['exec'])} {args} $@ {fork}\n")
        f.write("\n")
        if kill_trap:
            f.write("pid=$!\n")
            f.write("\n")
            f.write("wait $pid\n")
            f.write("\n")
            f.write("if [[ $? -gt 128 ]]; then\n")
            f.write("    kill -9 $pid\n")
            f.write("fi\n")
            f.write("\n")
        if "post_exec_commands" in exec_config and len(
                exec_config["post_exec_commands"]) > 0:
            for cmd in exec_config["post_exec_commands"]:
                f.write(f"{resolve_vars(cmd)}\n")
            f.write("\n")
        console.print(f"Installed executable '{name}' into {self.bin_path}.")

    def install_executable(self, name, exec_config, kill_trap, fork):
        if not os.path.exists(self.bin_path):
            os.makedirs(self.bin_path, exist_ok=True)

        exec_path = os.path.join(self.bin_path, name)

        with open(exec_path, "w", encoding="utf-8") as file:
            self._write_executable(name, file, exec_config, kill_trap, fork)
        os.chmod(exec_path, 0o770)

        self.installed_executable.append(name)

    def purge_unexplained_executables(self, known_executables_in_workspace):
        if not os.path.exists(self.bin_path):
            return
        for file in os.listdir(self.bin_path):
            if file not in known_executables_in_workspace:
                exec_path = os.path.join(self.bin_path, file)
                if os.path.exists(exec_path):
                    os.remove(exec_path)