import os
import pytest

from armarx_setup.core.config import axii_config
from armarx_setup.core.util.commands import run
from armarx_setup.core.workspace import Workspace


cmd_args = {
    "capture_output": True,
    "quiet": True
}


@pytest.fixture()
def test_workspace():
    """
    Fixture to create a workspace, supply it as "test_workspace", and destroy it afterwards.
    """

    workspace_name = "test_workspace"
    workspace_path = os.path.join("/tmp", workspace_name)

    run(f"axii workspace create {workspace_path} {workspace_name}", **cmd_args)
    axii_config.load_known_workspaces()

    workspace = Workspace.load_workspace_by_path(workspace_path)

    # Simulate activating workspace.
    os.environ["ARMARX_WORKSPACE"] = workspace_path

    yield workspace

    run(f"axii workspace purge {workspace_name} --yes")

    # Simulate deactivating workspace.
    del os.environ["ARMARX_WORKSPACE"]





