import os

from armarx_setup.core.module import common
from armarx_setup.core.module.prepare import Extract

from tests.unit.core.module import DummyContext


def test_absolute_creation():
    data = {
        "file": "/dev/null/does_not-exist.tar.gz",
        "ctx": DummyContext()
    }
    extract = Extract(**data)

    assert extract.file == "/dev/null/does_not-exist.tar.gz"
    assert extract.file_ext == ".tar.gz"
    assert extract.extract_into == "/dev/null/does_not-exist"


def test_relative_creation():
    ctx = DummyContext()
    data = {
        "file": "does_not-exist.tar.gz",
        "ctx": ctx
    }
    extract = Extract(**data)

    module_path = ctx.path

    assert extract.file == os.path.join(module_path, "does_not-exist.tar.gz")
    assert extract.file_ext == ".tar.gz"
    assert extract.extract_into == os.path.join(module_path, "does_not-exist")


def test_file_not_existing():
    data = {
        "file": "/dev/null/does_not-exist.tar.gz",
        "ctx": DummyContext()
    }
    extract = Extract(**data)

    step_result = extract()

    assert step_result.status == common.StepResultStatus.FAILURE
    assert step_result.summary == "Archive does not exist"


def test_env_var():
    os.environ["THIS_IS_A_TEST"] = "test_value"

    data = {
        "file": "/test/$THIS_IS_A_TEST.tar.gz",
        "extract_into": "/data/$THIS_IS_A_TEST/",
        "ctx": DummyContext()
    }
    extract = Extract(**data)

    assert extract.file == "/test/test_value.tar.gz"
    assert extract.extract_into == "/data/test_value/"
