import pytest

from armarx_setup.core.module import Module
from armarx_setup.core.workspace import Workspace
from armarx_setup.core.util.json import switch_arch

ws = Workspace(path="", name="")

os_info_x86 = switch_arch.ArchInfo(
    architecture_id="x86_64", bits="64bit",
    platform="Linux-5.4.0-135-generic-x86_64-with-Ubuntu-18.04-bionic"
)
os_info_aarch = switch_arch.ArchInfo(
    architecture_id="aarch64", bits="64bit",
    platform="Linux-4.9.253-gcca4bf6-aarch64-with-Ubuntu-18.04-bionic"
)
os_info_default = switch_arch.ArchInfo("", "", "")

MODULE_NAME = "test/test_arch_switch_in_load_module"

parameters = [
    (os_info_x86, "https://github.com/test_x86_64.tar.gz", "$MODULE_PATH/x86_64/:$PATH", None,
     "$MODULE_PATH/only_x86_64/"),
    (os_info_aarch, "https://github.com/test_aarch64.tar.gz",
     "$MODULE_PATH/aarch64/:$PATH", None, None),
    (os_info_default, None, "$MODULE_PATH/default/:$PATH", "$MODULE_PATH/only_default/", None),
]


@pytest.mark.parametrize("arch_info, url, path, only_default, only_x86", parameters)
def test_load_meta_default_compiler_x86(
        arch_info: switch_arch.ArchInfo,
        url: str,
        path: str,
        only_default: [str, None],
        only_x86: [str, None]
):
    '''
    Test function to check that the switch_arch directive resolves correctly in the
    load module function

    :param arch_info: mock arch info struct
    :param url: ground truth url of the module
    :param path: grount truth path of the module
    :param only_default: ground truth for only_default member
    :param only_x86: ground truth for only_x86 member

    '''
    switch_arch.arch_info = arch_info

    module = Module.load_info(MODULE_NAME, ws=ws)
    assert module is not None
    # console.print(module)

    assert module.update is not None, module

    archive = module.update.archive

    if url is None:
        assert archive.url is url
    else:
        assert archive.url == url

    assert module.install is not None, module

    env = module.install.env.env
    # console.print(env)
    assert len(env) > 0, env

    assert env.get("PATH", None) == path, env
    assert env.get("only_default", None) == only_default, env
    assert env.get("only_x86", None) == only_x86, env

    # reset global arch_info to None
    switch_arch.arch_info = None
